Learn R Programming

epsiwal (version 0.2.0)

epsiwal-NEWS: News for package 'epsiwal':

Description

News for package ‘epsiwal’

Arguments

<a href="https://cran.r-project.org/package=epsiwal"><span class="pkg">epsiwal</span></a> Initial Version 0.2.0 (2026-06-08)

  • fix numerical stability issues in ptruncnorm and downstream utilities (CIs).

  • add MLE estimator of Reid, Taylor, Tibshirani.

  • add helper functions for the case of conditioning on the max of a vector.

<a href="https://cran.r-project.org/package=epsiwal"><span class="pkg">epsiwal</span></a> Initial Version 0.1.0 (2019-06-28)

  • first CRAN release.