Learn R Programming

epsiwal (version 0.2.0)

pconnorm: pconnorm .

Description

CDF of the conditional normal variate.

Usage

pconnorm(
  y,
  A,
  b,
  eta,
  mu = NULL,
  Sigma = NULL,
  Sigma_eta = Sigma %*% eta,
  eta_mu = as.numeric(t(eta) %*% mu),
  lower.tail = TRUE,
  log.p = FALSE
)

Value

The CDF.

Arguments

y

an \(n\) vector, assumed multivariate normal with mean \(\mu\) and covariance \(\Sigma\).

A

an \(k \times n\) matrix of constraints.

b

a \(k\) vector of inequality limits.

eta

an \(n\) vector of the test contrast, \(\eta\).

mu

an \(n\) vector of the population mean, \(\mu\). Not needed if eta_mu is given.

Sigma

an \(n \times n\) matrix of the population covariance, \(\Sigma\). Not needed if Sigma_eta is given.

Sigma_eta

an \(n\) vector of \(\Sigma \eta\).

eta_mu

the scalar \(\eta^{\top}\mu\).

lower.tail

logical; if TRUE (default), probabilities are P[X <= x] otherwise, P[X > x].

log.p

logical; if TRUE, probabilities p are returned as log(p).

Author

Steven E. Pav shabbychef@gmail.com

Details

Computes the CDF of the truncated normal conditional on linear constraints, as described in section 5 of Lee et al.

Let \(y\) be multivariate normal with mean \(\mu\) and covariance \(\Sigma\). Conditional on \(Ay \le b\) for conformable matrix \(A\) and vector \(b\) we compute the CDF of a truncated normal maximally aligned with \(\eta\). Inference depends on the population parameters only via \(\eta^{\top}\mu\) and \(\Sigma \eta\), and only these need to be given.

The test statistic is aligned with \(y\), meaning that an output p-value near one casts doubt on the null hypothesis that \(\eta^{\top}\mu\) is less than the posited value.

References

Lee, J. D., Sun, D. L., Sun, Y. and Taylor, J. E. "Exact post-selection inference, with application to the Lasso." Ann. Statist. 44, no. 3 (2016): 907-927. doi:10.1214/15-AOS1371. https://arxiv.org/abs/1311.6238

See Also

the confidence interval function, ci_connorm, the MLE function, mle_connorm.