pconnorm_max: pconnorm_max .

View source: R/pconnorm.r

pconnorm_maxR Documentation

pconnorm_max .

Description

CDF of the conditional normal variate, conditioning on the max.

Usage

pconnorm_max(
  yk,
  yk1,
  mu_k,
  sigma = 1,
  rho = 0,
  lower.tail = TRUE,
  log.p = FALSE
)

Arguments

yk

the observed maximum value, y_k.

yk1

a vector of the other observed values, y_{k1}, or just the scalar second largest value.

mu_k

the scalar mean of the maximal element \mu_k.

sigma

the common standard deviation.

rho

the common correlation.

lower.tail

logical; if TRUE (default), probabilities are P[X <= x] otherwise, P[X > x].

log.p

logical; if TRUE, probabilities p are returned as log(p).

Details

Computes the CDF of the conditional maximum of a normal vector using the truncated normal from the polyhedral lemma. Let y be multivariate normal where the maximal observed element is known to have mean \mu_k, and the vector has known covariance \Sigma. We assume that \Sigma is compound symmetric with common variance \sigma^2 and common correlation \rho.

Conditional on y_k \ge y_i for all i, we compute the CDF of y_k

Value

The CDF.

Author(s)

Steven E. Pav shabbychef@gmail.com

References

Lee, J. D., Sun, D. L., Sun, Y. and Taylor, J. E. "Exact post-selection inference, with application to the Lasso." Ann. Statist. 44, no. 3 (2016): 907-927. doi:10.1214/15-AOS1371. https://arxiv.org/abs/1311.6238

See Also

the general CDF function, pconnorm, the MLE function, mle_connorm_max, the confidence interval function, ci_connorm_max.


epsiwal documentation built on June 10, 2026, 9:06 a.m.