Learn R Programming

epsiwal (version 0.2.0)

ci_connorm_max: ci_connorm_max .

Description

Confidence intervals on normal mean, conditioning on the max.

Usage

ci_connorm_max(
  yk,
  yk1,
  sigma = 1,
  rho = 0,
  p = c(level/2, 1 - (level/2)),
  level = 0.05
)

Value

The values of \(\mu_k\) which have the corresponding CDF.

Arguments

yk

the observed maximum value, \(y_k\).

yk1

a vector of the other observed values, \(y_{k1}\), or just the scalar second largest value.

sigma

the common standard deviation.

rho

the common correlation.

p

a vector of probabilities for which we return equivalent \(\eta^{\top}\mu\).

level

if p is not given, we set it by default to c(level/2,1-level/2).

Author

Steven E. Pav shabbychef@gmail.com

Details

Computes the confidence interval of unknown mean of a normal vector conditional on the one element being the maximum.

Let \(y\) be multivariate normal with unknown mean \(\mu\) and known covariance \(\Sigma\). We assume that \(\Sigma\) is compound symmetric with common variance \(\sigma^2\) and common correlation \(\rho\).

Conditional on \(y_k \ge y_i\) for all \(i\), we compute the confidence interval of \(\mu_k\).

References

Lee, J. D., Sun, D. L., Sun, Y. and Taylor, J. E. "Exact post-selection inference, with application to the Lasso." Ann. Statist. 44, no. 3 (2016): 907-927. doi:10.1214/15-AOS1371. https://arxiv.org/abs/1311.6238

See Also

the CDF function, pconnorm, the MLE function, mle_connorm_max, the more general version, ci_connorm.