| mle_connorm | R Documentation |
Maximum likelihood estimate of normal mean, subject to linear constraints.
mle_connorm(y, A, b, eta, Sigma = NULL, Sigma_eta = Sigma %*% eta, ...)
y |
an |
A |
an |
b |
a |
eta |
an |
Sigma |
an |
Sigma_eta |
an |
... |
dots are passed to |
Computes the maximum likelihood estimate of unknown mean of a normal vector conditional on linear constraints.
Let y be multivariate normal with unknown mean \mu
and known covariance \Sigma. Conditional on Ay \le b
for conformable matrix A and vector b, and given
constrast vector eta, we compute
the maximum likelihood estimate of \eta^{\top}\mu.
The maximum likelihood estimate of \eta^{\top}\mu.
Steven E. Pav shabbychef@gmail.com
Reid, S., Taylor, J. and Tibshirani, R. "Post-selection point and interval estimation of signal sizes in Gaussian samples." Can. J. Statistics. 45, no. 2 (2017): 128-148. doi:10.1002/cjs.11320. https://arxiv.org/abs/1405.3340
the confidence interval function, ci_connorm,
the CDF function, pconnorm,
the special case code for conditioning on the max, mle_connorm_max
set.seed(1234)
n <- 10
y <- rnorm(n)
A <- matrix(rnorm(n*(n-3)),ncol=n)
b <- A%*%y + runif(nrow(A))
Sigma <- diag(runif(n))
mu <- rnorm(n)
eta <- rnorm(n)
mval <- mle_connorm(y=y,A=A,b=b,eta=eta,Sigma=Sigma)
# try again, but control tolerance:
mval <- mle_connorm(y=y,A=A,b=b,eta=eta,Sigma=Sigma,tol=1e-8)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.