| mle_connorm_max | R Documentation |
Maximum likelihood estimate of normal mean, conditioning on the max.
mle_connorm_max(yk, yk1, sigma = 1, rho = 0, ...)
yk |
the observed maximum value, |
yk1 |
a vector of the other observed values, |
sigma |
the common standard deviation. |
rho |
the common correlation. |
... |
dots are passed to |
Computes the maximum likelihood estimate of unknown mean of a normal vector conditional on the one element being the maximum.
Let y be multivariate normal with unknown mean \mu
and known covariance \Sigma. We assume that \Sigma
is compound symmetric with common variance \sigma^2 and
common correlation \rho.
Conditional on y_k \ge y_i for all i,
we compute the maximum likelihood estimate of \mu_k.
The maximum likelihood estimate of \mu_k.
Steven E. Pav shabbychef@gmail.com
Reid, S., Taylor, J. and Tibshirani, R. "Post-selection point and interval estimation of signal sizes in Gaussian samples." Can. J. Statistics. 45, no. 2 (2017): 128-148. doi:10.1002/cjs.11320. https://arxiv.org/abs/1405.3340
the confidence interval function, ci_connorm_max,
the CDF function, pconnorm,
the more general version, mle_connorm.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.